# Topsis-jasleen-102003238
Topsis implementation in python. Used as a command line tool to generate topsis score and ranks of the given input data file along with weights and impacts. The method helps to find the best alternative from a set of options by comparing each option's similarity to an ideal solution and a negative-ideal solution, which are defined based on the decision-maker's preferences.

## Installation

`pip install Topsis-jasleen-102003238`

## How to use it?

Open the terminal / cmd and type topsis <input_filename.csv> <"Weights"> <"Impacts"> <output_filename.csv>

## License

© 2023 jasleen

This repository is licensed under the MIT license. See LICENSE for details.
